@@ -1,6 +1,6 @@
 from typing import Union, Optional, List
 
-from pydantic import StrictStr, StrictBool
+from pydantic import StrictStr, StrictBool, StrictInt
 from tensorfn.config import TypedConfig, override, Config
 from tensorfn import checker
 
@@ -8,9 +8,10 @@ from tensorfn import checker
 class Local(TypedConfig):
     __type__ = "local"
     path: StrictStr
+    keep: StrictInt = -1
 
     def make(self, **kwargs):
-        argument = override(kwargs, path=self.path)
+        argument = override(kwargs, path=self.path, keep=self.keep)
 
         return checker.Local(**argument)
 
@@ -21,6 +22,7 @@ class S3(TypedConfig):
     path: StrictStr
     access_key: StrictStr
     secret_key: StrictStr
+    keep: StrictInt = -1
     endpoint: Optional[StrictStr]
     show_progress: StrictBool
 
@@ -31,6 +33,7 @@ class S3(TypedConfig):
             path=self.path,
             access_key=self.access_key,
             secret_key=self.secret_key,
+            keep=self.keep,
             endpoint=self.endpoint,
             show_progress=self.show_progress,
         )
